
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.123'
version = '1.2.123'
full_version = '1.2.123'
git_revision = 'ee5eb8fbea970f80592ad5e522b4bad8ffb50299'
release = True

if not release:
    version = full_version
    short_version += ".dev"
